@@ -195,12 +195,12 @@ class Document(proto.Message):
 
     input_config = proto.Field(proto.MESSAGE, number=1, message=io.DocumentInputConfig,)
 
-    document_text = proto.Field(proto.MESSAGE, number=2, message=TextSnippet,)
+    document_text = proto.Field(proto.MESSAGE, number=2, message="TextSnippet",)
 
     layout = proto.RepeatedField(proto.MESSAGE, number=3, message=Layout,)
 
     document_dimensions = proto.Field(
-        proto.MESSAGE, number=4, message=DocumentDimensions,
+        proto.MESSAGE, number=4, message="DocumentDimensions",
     )
 
     page_count = proto.Field(proto.INT32, number=5)
@@ -247,15 +247,17 @@ class ExamplePayload(proto.Message):
             Example relational table row.
     """
 
-    image = proto.Field(proto.MESSAGE, number=1, oneof="payload", message=Image,)
+    image = proto.Field(proto.MESSAGE, number=1, oneof="payload", message="Image",)
 
     text_snippet = proto.Field(
-        proto.MESSAGE, number=2, oneof="payload", message=TextSnippet,
+        proto.MESSAGE, number=2, oneof="payload", message="TextSnippet",
     )
 
-    document = proto.Field(proto.MESSAGE, number=4, oneof="payload", message=Document,)
+    document = proto.Field(
+        proto.MESSAGE, number=4, oneof="payload", message="Document",
+    )
 
-    row = proto.Field(proto.MESSAGE, number=3, oneof="payload", message=Row,)
+    row = proto.Field(proto.MESSAGE, number=3, oneof="payload", message="Row",)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
