@@ -171,7 +171,7 @@ class ImageObjectDetectionEvaluationMetrics(proto.Message):
     evaluated_bounding_box_count = proto.Field(proto.INT32, number=1)
 
     bounding_box_metrics_entries = proto.RepeatedField(
-        proto.MESSAGE, number=2, message=BoundingBoxMetricsEntry,
+        proto.MESSAGE, number=2, message="BoundingBoxMetricsEntry",
     )
 
     bounding_box_mean_average_precision = proto.Field(proto.FLOAT, number=3)
@@ -208,7 +208,7 @@ class VideoObjectTrackingEvaluationMetrics(proto.Message):
     evaluated_bounding_box_count = proto.Field(proto.INT32, number=2)
 
     bounding_box_metrics_entries = proto.RepeatedField(
-        proto.MESSAGE, number=4, message=BoundingBoxMetricsEntry,
+        proto.MESSAGE, number=4, message="BoundingBoxMetricsEntry",
     )
 
     bounding_box_mean_average_precision = proto.Field(proto.FLOAT, number=6)
