@@ -106,12 +106,12 @@ def test_prediction_service_client_from_service_account_file(client_class):
     ) as factory:
         factory.return_value = creds
         client = client_class.from_service_account_file("dummy/file/path.json")
-        assert client._transport._credentials == creds
+        assert client.transport._credentials == creds
 
         client = client_class.from_service_account_json("dummy/file/path.json")
-        assert client._transport._credentials == creds
+        assert client.transport._credentials == creds
 
-        assert client._transport._host == "automl.googleapis.com:443"
+        assert client.transport._host == "automl.googleapis.com:443"
 
 
 def test_prediction_service_client_get_transport_class():
@@ -471,7 +471,7 @@ def test_predict(
     request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.predict), "__call__") as call:
+    with mock.patch.object(type(client.transport.predict), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = prediction_service.PredictResponse()
 
@@ -484,6 +484,7 @@ def test_predict(
         assert args[0] == prediction_service.PredictRequest()
 
     # Establish that the response is the type that we expect.
+
     assert isinstance(response, prediction_service.PredictResponse)
 
 
@@ -492,17 +493,19 @@ def test_predict_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_predict_async(transport: str = "grpc_asyncio"):
+async def test_predict_async(
+    transport: str = "grpc_asyncio", request_type=prediction_service.PredictRequest
+):
     client = PredictionServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = prediction_service.PredictRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._client._transport.predict), "__call__") as call:
+    with mock.patch.object(type(client.transport.predict), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             prediction_service.PredictResponse()
@@ -514,12 +517,17 @@ async def test_predict_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == prediction_service.PredictRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, prediction_service.PredictResponse)
 
 
+@pytest.mark.asyncio
+async def test_predict_async_from_dict():
+    await test_predict_async(request_type=dict)
+
+
 def test_predict_field_headers():
     client = PredictionServiceClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -529,7 +537,7 @@ def test_predict_field_headers():
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.predict), "__call__") as call:
+    with mock.patch.object(type(client.transport.predict), "__call__") as call:
         call.return_value = prediction_service.PredictResponse()
 
         client.predict(request)
@@ -556,7 +564,7 @@ async def test_predict_field_headers_async():
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._client._transport.predict), "__call__") as call:
+    with mock.patch.object(type(client.transport.predict), "__call__") as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             prediction_service.PredictResponse()
         )
@@ -577,7 +585,7 @@ def test_predict_flattened():
     client = PredictionServiceClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.predict), "__call__") as call:
+    with mock.patch.object(type(client.transport.predict), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = prediction_service.PredictResponse()
 
@@ -628,7 +636,7 @@ async def test_predict_flattened_async():
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._client._transport.predict), "__call__") as call:
+    with mock.patch.object(type(client.transport.predict), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = prediction_service.PredictResponse()
 
@@ -690,7 +698,7 @@ def test_batch_predict(
     request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.batch_predict), "__call__") as call:
+    with mock.patch.object(type(client.transport.batch_predict), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = operations_pb2.Operation(name="operations/spam")
 
@@ -711,19 +719,19 @@ def test_batch_predict_from_dict():
 
 
 @pytest.mark.asyncio
-async def test_batch_predict_async(transport: str = "grpc_asyncio"):
+async def test_batch_predict_async(
+    transport: str = "grpc_asyncio", request_type=prediction_service.BatchPredictRequest
+):
     client = PredictionServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = prediction_service.BatchPredictRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.batch_predict), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.batch_predict), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             operations_pb2.Operation(name="operations/spam")
@@ -735,12 +743,17 @@ async def test_batch_predict_async(transport: str = "grpc_asyncio"):
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == prediction_service.BatchPredictRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, future.Future)
 
 
+@pytest.mark.asyncio
+async def test_batch_predict_async_from_dict():
+    await test_batch_predict_async(request_type=dict)
+
+
 def test_batch_predict_field_headers():
     client = PredictionServiceClient(credentials=credentials.AnonymousCredentials(),)
 
@@ -750,7 +763,7 @@ def test_batch_predict_field_headers():
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.batch_predict), "__call__") as call:
+    with mock.patch.object(type(client.transport.batch_predict), "__call__") as call:
         call.return_value = operations_pb2.Operation(name="operations/op")
 
         client.batch_predict(request)
@@ -777,9 +790,7 @@ async def test_batch_predict_field_headers_async():
     request.name = "name/value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.batch_predict), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.batch_predict), "__call__") as call:
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             operations_pb2.Operation(name="operations/op")
         )
@@ -800,7 +811,7 @@ def test_batch_predict_flattened():
     client = PredictionServiceClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client._transport.batch_predict), "__call__") as call:
+    with mock.patch.object(type(client.transport.batch_predict), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = operations_pb2.Operation(name="operations/op")
 
@@ -867,9 +878,7 @@ async def test_batch_predict_flattened_async():
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(
-        type(client._client._transport.batch_predict), "__call__"
-    ) as call:
+    with mock.patch.object(type(client.transport.batch_predict), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = operations_pb2.Operation(name="operations/op")
 
@@ -971,7 +980,7 @@ def test_transport_instance():
         credentials=credentials.AnonymousCredentials(),
     )
     client = PredictionServiceClient(transport=transport)
-    assert client._transport is transport
+    assert client.transport is transport
 
 
 def test_transport_get_channel():
@@ -1007,7 +1016,7 @@ def test_transport_adc(transport_class):
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
     client = PredictionServiceClient(credentials=credentials.AnonymousCredentials(),)
-    assert isinstance(client._transport, transports.PredictionServiceGrpcTransport,)
+    assert isinstance(client.transport, transports.PredictionServiceGrpcTransport,)
 
 
 def test_prediction_service_base_transport_error():
@@ -1107,7 +1116,7 @@ def test_prediction_service_host_no_port():
             api_endpoint="automl.googleapis.com"
         ),
     )
-    assert client._transport._host == "automl.googleapis.com:443"
+    assert client.transport._host == "automl.googleapis.com:443"
 
 
 def test_prediction_service_host_with_port():
@@ -1117,7 +1126,7 @@ def test_prediction_service_host_with_port():
             api_endpoint="automl.googleapis.com:8000"
         ),
     )
-    assert client._transport._host == "automl.googleapis.com:8000"
+    assert client.transport._host == "automl.googleapis.com:8000"
 
 
 def test_prediction_service_grpc_transport_channel():
@@ -1129,6 +1138,7 @@ def test_prediction_service_grpc_transport_channel():
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
+    assert transport._ssl_channel_credentials == None
 
 
 def test_prediction_service_grpc_asyncio_transport_channel():
@@ -1140,6 +1150,7 @@ def test_prediction_service_grpc_asyncio_transport_channel():
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
+    assert transport._ssl_channel_credentials == None
 
 
 @pytest.mark.parametrize(
@@ -1185,8 +1196,13 @@ def test_prediction_service_transport_channel_mtls_with_client_cert_source(
                 scopes=("https://www.googleapis.com/auth/cloud-platform",),
                 ssl_credentials=mock_ssl_cred,
                 quota_project_id=None,
+                options=[
+                    ("grpc.max_send_message_length", -1),
+                    ("grpc.max_receive_message_length", -1),
+                ],
             )
             assert transport.grpc_channel == mock_grpc_channel
+            assert transport._ssl_channel_credentials == mock_ssl_cred
 
 
 @pytest.mark.parametrize(
@@ -1225,6 +1241,10 @@ def test_prediction_service_transport_channel_mtls_with_adc(transport_class):
                 scopes=("https://www.googleapis.com/auth/cloud-platform",),
                 ssl_credentials=mock_ssl_cred,
                 quota_project_id=None,
+                options=[
+                    ("grpc.max_send_message_length", -1),
+                    ("grpc.max_receive_message_length", -1),
+                ],
             )
             assert transport.grpc_channel == mock_grpc_channel
 
@@ -1233,7 +1253,7 @@ def test_prediction_service_grpc_lro_client():
     client = PredictionServiceClient(
         credentials=credentials.AnonymousCredentials(), transport="grpc",
     )
-    transport = client._transport
+    transport = client.transport
 
     # Ensure that we have a api-core operations client.
     assert isinstance(transport.operations_client, operations_v1.OperationsClient,)
@@ -1246,7 +1266,7 @@ def test_prediction_service_grpc_lro_async_client():
     client = PredictionServiceAsyncClient(
         credentials=credentials.AnonymousCredentials(), transport="grpc_asyncio",
     )
-    transport = client._client._transport
+    transport = client.transport
 
     # Ensure that we have a api-core operations client.
     assert isinstance(transport.operations_client, operations_v1.OperationsAsyncClient,)
@@ -1255,6 +1275,132 @@ def test_prediction_service_grpc_lro_async_client():
     assert transport.operations_client is transport.operations_client
 
 
+def test_model_path():
+    project = "squid"
+    location = "clam"
+    model = "whelk"
+
+    expected = "projects/{project}/locations/{location}/models/{model}".format(
+        project=project, location=location, model=model,
+    )
+    actual = PredictionServiceClient.model_path(project, location, model)
+    assert expected == actual
+
+
+def test_parse_model_path():
+    expected = {
+        "project": "octopus",
+        "location": "oyster",
+        "model": "nudibranch",
+    }
+    path = PredictionServiceClient.model_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = PredictionServiceClient.parse_model_path(path)
+    assert expected == actual
+
+
+def test_common_billing_account_path():
+    billing_account = "cuttlefish"
+
+    expected = "billingAccounts/{billing_account}".format(
+        billing_account=billing_account,
+    )
+    actual = PredictionServiceClient.common_billing_account_path(billing_account)
+    assert expected == actual
+
+
+def test_parse_common_billing_account_path():
+    expected = {
+        "billing_account": "mussel",
+    }
+    path = PredictionServiceClient.common_billing_account_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = PredictionServiceClient.parse_common_billing_account_path(path)
+    assert expected == actual
+
+
+def test_common_folder_path():
+    folder = "winkle"
+
+    expected = "folders/{folder}".format(folder=folder,)
+    actual = PredictionServiceClient.common_folder_path(folder)
+    assert expected == actual
+
+
+def test_parse_common_folder_path():
+    expected = {
+        "folder": "nautilus",
+    }
+    path = PredictionServiceClient.common_folder_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = PredictionServiceClient.parse_common_folder_path(path)
+    assert expected == actual
+
+
+def test_common_organization_path():
+    organization = "scallop"
+
+    expected = "organizations/{organization}".format(organization=organization,)
+    actual = PredictionServiceClient.common_organization_path(organization)
+    assert expected == actual
+
+
+def test_parse_common_organization_path():
+    expected = {
+        "organization": "abalone",
+    }
+    path = PredictionServiceClient.common_organization_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = PredictionServiceClient.parse_common_organization_path(path)
+    assert expected == actual
+
+
+def test_common_project_path():
+    project = "squid"
+
+    expected = "projects/{project}".format(project=project,)
+    actual = PredictionServiceClient.common_project_path(project)
+    assert expected == actual
+
+
+def test_parse_common_project_path():
+    expected = {
+        "project": "clam",
+    }
+    path = PredictionServiceClient.common_project_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = PredictionServiceClient.parse_common_project_path(path)
+    assert expected == actual
+
+
+def test_common_location_path():
+    project = "whelk"
+    location = "octopus"
+
+    expected = "projects/{project}/locations/{location}".format(
+        project=project, location=location,
+    )
+    actual = PredictionServiceClient.common_location_path(project, location)
+    assert expected == actual
+
+
+def test_parse_common_location_path():
+    expected = {
+        "project": "oyster",
+        "location": "nudibranch",
+    }
+    path = PredictionServiceClient.common_location_path(**expected)
+
+    # Check that the path construction is reversible.
+    actual = PredictionServiceClient.parse_common_location_path(path)
+    assert expected == actual
+
+
 def test_client_withDEFAULT_CLIENT_INFO():
     client_info = gapic_v1.client_info.ClientInfo()
 
